@@ -9,4 +9,4 @@ def setup_ioc():
     if not ioc.is_satisfied('JOSEKeyResolver'):
         ioc.provide('JOSEKeyResolver', JOSEKeyResolver())
     if not ioc.is_satisfied('JOSEPayloadDecoder'):
-        ioc.provide('JOSEPayloadDecoder', JOSEKeyResolver())
+        ioc.provide('JOSEPayloadDecoder', JOSEPayloadDecoder())
