@@ -98,3 +98,17 @@ class UnsupportedEncryptionAlgorithm(BaseJoseException):
     def __init__(self, algorithm):
         detail = f"The '{algorithm}' is not supported."
         super().__init__(detail=detail)
+
+
+class NotEffective(BaseJoseException):
+    code = 'CREDENTIAL_NOT_EFFECTIVE'
+    http_status_code = 403
+    message = "The JSON Web Token (JWT) is not effective yet."
+
+
+class MissingClaims(BaseJoseException):
+    code = 'CREDENTIAL_NOT_EFFECTIVE'
+    http_status_code = 403
+    message = (
+        "The JSON Web Token (JWT) didn't provide the required claims."
+    )
