@@ -2,6 +2,7 @@
 from typing import Any
 
 from unimatrix.ext import crypto
+from unimatrix.ext.crypto.trustedpublickey import TrustedPublicKey
 
 from .algorithms import ALGORITHM_MAPPING
 from .decoder import JOSEPayloadDecoder
@@ -39,6 +40,20 @@ class JSONWebSignature(crypto.Signable):
                 keyid=header.kid)
         )
 
+    @property
+    def kid(self) -> str:
+        """Returns the key identifier that was used to create the JWS."""
+        return self.header.kid
+
+    @property
+    def key(self) -> TrustedPublicKey:
+        """Return the :class:`unimatrix.ext.crypto.TrustedPublicKey` instance
+        that was used to create the JWS. It is assumed that this property is
+        only invoked on signatures that are succesfully verified. If the
+        header did not contain the ``kid`` claim, then return ``None``.
+        """
+        return None if self.kid is None else crypto.trust.get(self.kid)
+
     def __init__(self, header, payload, signature=None):
         self.header = header or JOSEHeader()
         self.payload = payload
