@@ -162,6 +162,8 @@ class JSONWebToken:
         Returns:
             :class:`bool`
         """
+        if required is not None:
+            self.verify_presence(required)
         now = int(time.time())
         self.verify_expired(now=now, raise_exception=raise_exception)
         self.verify_not_before(now=now, raise_exception=raise_exception)
@@ -176,8 +178,6 @@ class JSONWebToken:
             self.verify_issuer(issuers, raise_exception=raise_exception)
         if scope is not None:
             self.verify_scopes(scope, raise_exception=raise_exception)
-        if required is not None:
-            self.verify_presence(required)
 
     def verify_expired(self, now=None, raise_exception=True):
         """Verifies that the JSON Web Token is not expired, based on the
@@ -221,7 +221,7 @@ class JSONWebToken:
             now = int(time.time())
         is_valid = self.nbf <= now
         if not is_valid and raise_exception:
-            raise self.NotEffective(self, now)
+            raise self.NotEffective
         return is_valid
 
     def verify_presence(self, claims: set, raise_exception=True) -> bool:
